# Slovar

Slovar is a dict-like object that can be filtered, collapsed, expanded, etc.

## Setting up & testing

    virtualenv .
    pip install -r requirements.test
    pytest
    pytest benchmarks/
